@@ -5,9 +5,9 @@
 """
 
 
-import degget
-import games_help
-import packages
+# import degget
+# import games_help
+# import packages
 
 
 # from degget import show
@@ -16,5 +16,5 @@ import packages
 
 
 __author__ = 'Superior_6564'
-__version__ = '0.0.4'
+__version__ = '0.0.5'
 __email__ = 'vip.klochayil@gmail.com'
